package org.codehaus.mojo.ship;

import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.logging.Log;
import org.codehaus.plexus.util.FileUtils;
import org.codehaus.plexus.util.IOUtil;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.Map;
import java.util.Set;

/**
 * Created by IntelliJ IDEA.
 * User: stephenc
 * Date: Nov 24, 2010
 * Time: 3:54:37 PM
 * To change this template use File | Settings | File Templates.
 */
public class ScriptEngineManager
{
    private final Set engines;

    public ScriptEngineManager()
    {
        engines = new LinkedHashSet();
        engines.add( new BeanShellScriptEngine() );
        engines.add( new GroovyScriptEngine() );
        engines.add( new WagonScriptEngine() );
    }

    public Object eval(URL script, String encoding, Map globalVariables, Log log)
        throws MojoExecutionException
    {
        ScriptEngine engine = null;
        Iterator i = engines.iterator();
        while ( i.hasNext() )
        {
            ScriptEngine e = (ScriptEngine) i.next();
            if ( script.getPath().endsWith("." + e.getExtension()) )
            {
                engine = e;
                break;
            }
        }
        if ( engine == null )
        {
            throw new MojoExecutionException( "Could not find a script engine to execute " + script );
        }
        InputStream inputStream = null;
        try
        {
            inputStream = script.openStream();
            return engine.eval( IOUtil.toString(inputStream, encoding), globalVariables );
        }
        catch ( ScriptException e )
        {
            throw new MojoExecutionException( "Ship script failed", e );
        }
        catch ( IOException e )
        {
            throw new MojoExecutionException( e.getLocalizedMessage(), e );
        }
        finally
        {
            IOUtil.close(inputStream);
        }
    }

    public boolean isScriptPath( String path )
    {
        Iterator i = engines.iterator();
        while ( i.hasNext() )
        {
            ScriptEngine e = (ScriptEngine) i.next();
            if ( path.endsWith("." + e.getExtension()) )
            {
                return true;
            }
        }
        return false;
    }

}
